realtimekit_ui library

Classes

ActiveTab
AudioDevice
BorderToken
ChatErrorUtils
ChatMessage
ErrorStringProvider<T extends RtkError>
FileMessage
GridPagesInfo
HostErrorUtils
ImageMessage
LinearColorSwatch
LivestreamView
MeetingErrorUtils
MessageRateLimit
PluginView
Poll
PollOption
PollsErrorUtils
Utility class for polls error handling
Pubspec
RangedColorSwatch
RealtimekitClient
RealtimeKitUI
RealtimeKitUIBuilder
RealtimeKitUIInfo
RtkAudioIndicatorIconWidget
RtkBase64Encoding
RtkButtonController
RtkChat
RtkChatEventListener
RtkChatIconWidget
RtkColorSwatch
RtkColorToken
RtkConfig
RtkDataEventListener
RtkDesignTokens
RtkJoinButton
RtkLeaveButton
RtkLeaveMeetingDialog
RtkLivestreamData
RtkLivestreamEventListener
RtkMeetingInfo
RtkMeetingParticipant
RtkMeetingRoomEventListener
RtkMeetingTitle
RtkMeta
RtkNameTag
RtkParticipants
RtkParticipants represents all the participants in the meeting (except the local user). It provides views to the current participants in the meeting as well as methods to modify them.
RtkParticipantsEventListener
RtkParticipantsIconWidget
RtkParticipantTile
RtkPlugin
RtkPluginIconWidget
RtkPluginsEventListener
RtkPollsEventListener
RtkPollsIconWidget
RtkPollsScreen
RtkProvider
RtkRecordingEventListener
RtkReleaseResourcesButton
DyteReleaseResourceButton widget is to be used when client exits the SDK before joining room such as waiting room or setup screen.
RtkRemoteParticipant
RtkSelfAudioToggleButton
RtkSelfEventListener
RtkSelfParticipant
RtkSelfVideoToggleButton
RtkSetupScreen
RtkStage
RtkStageEventListener
RtkWaitlistEventListener
ScreenshareView
SelfPermissions
SocketConnectionState
TextMessage
VideoDevice
VideoView

Extensions

ColorsUtils on Color

Functions

getColorFromStringHex(String hex) Color
returns a Color object by taking a String hex in the format of "#FFFFFF"
getErrorDataStringImpl(RtkError error) String