RealtimeKitUIBuilder class

Properties

arbPath String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiKitInfo RealtimeKitUIInfo
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build({required RealtimeKitUIInfo uiKitInfo, String? arbPath, RealtimekitClient? meeting, bool skipSetupPage = false}) RealtimeKitUI
dispose() → void