RtkBorderRadius enum

Inheritance
Available extensions

Values

sharp → const RtkBorderRadius
const RtkBorderRadius("sharp")
rounded → const RtkBorderRadius
const RtkBorderRadius("rounded")
extrarounded → const RtkBorderRadius
const RtkBorderRadius("extrarounded")
circular → const RtkBorderRadius
const RtkBorderRadius("circular")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) RtkBorderRadius

Constants

values → const List<RtkBorderRadius>
A constant List of the values in this enum, in order of their declaration.