RtkMeetingInfo class

Constructors

RtkMeetingInfo({required String authToken, String baseDomain = 'dyte.io', String displayName = 'Hello from Flutter', bool enableAudio = true, bool enableVideo = true})
RtkMeetingInfo.fromJson(String source)
factory
RtkMeetingInfo.fromMap(Map<String, dynamic> map)
factory

Properties

authToken String
final
baseDomain String
final
displayName String
final
enableAudio bool
final
enableVideo bool
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? authToken, bool? enableAudio, bool? enableVideo, String? baseDomain}) RtkMeetingInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(covariant RtkMeetingInfo other) bool
The equality operator.
override