SelfPermissions class
Constructors
- SelfPermissions({required ChatPermissions chat, required HostPermissions host, required MediaPermissions media, required PluginPermissions plugin, required PollPermissions poll, required MiscellaneousPermissions miscellaneous, required LivestreamPermissions livestream, required ParticipantPresetConfig userConfig})
- SelfPermissions.empty()
-
factory
- SelfPermissions.fromJson(String source)
-
factory
-
SelfPermissions.fromMap(Map<
String, dynamic> map) -
factory
Properties
- chat → ChatPermissions
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → HostPermissions
-
final
- livestream → LivestreamPermissions
-
final
- media → MediaPermissions
-
final
- miscellaneous → MiscellaneousPermissions
-
final
- plugin → PluginPermissions
-
final
- poll → PollPermissions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userConfig → ParticipantPresetConfig
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited