VideoDevice class

Constructors

VideoDevice({required String id, required VideoDeviceType type, required CameraType cameraType})
VideoDevice.fromJson(String source)
factory
VideoDevice.fromMap(Map<String, dynamic> map)
factory

Properties

cameraType → CameraType
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type VideoDeviceType
final

Methods

copyWith({String? id, VideoDeviceType? type, CameraType? cameraType}) VideoDevice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(covariant VideoDevice other) bool
The equality operator.
override